@@ -230,8 +230,13 @@ class EpoptesGui(object):
         # Open vncviewer in listen mode
         if self.vncviewer is None:
             self.vncviewerport = self.findUnusedPort()
-            self.vncviewer = subprocess.Popen(
-                ['xvnc4viewer', '-listen', str(self.vncviewerport)])
+            # If the user installed ssvnc, prefer it over xvnc4viewer
+            if os.path.isfile('/usr/bin/ssvncviewer'):
+                self.vncviewer = subprocess.Popen(['ssvncviewer',
+                    '-multilisten', str(self.vncviewerport-5500)])
+            else:
+                self.vncviewer = subprocess.Popen(['xvnc4viewer',
+                    '-listen', str(self.vncviewerport)])
 
         # And, tell the clients to connect to the server
         self.execOnSelectedClients([cmd, self.vncviewerport])
@@ -430,7 +435,10 @@ class EpoptesGui(object):
 
     #FIXME: Remove the second parameter, find a better way
     def on_tb_client_properties_clicked(self, widget=None):
-        ClientInformation(self.getSelectedClients(), self.daemon.command).run()
+        dlg = ClientInformation(self.getSelectedClients(), self.daemon.command)
+        if self.isDefaultGroupSelected():
+            dlg.edit_button.set_sensitive(False)
+        dlg.run()
         self.setLabel(self.getSelectedClients()[0])
 
 
